@@ -1,6 +1,7 @@
 #' The Hypergeometric distribution
 #'
-#' \lifecycle{stable}
+#' @description
+#' `r lifecycle::badge('stable')`
 #'
 #' To understand the HyperGeometric distribution, consider a set of
 #' \eqn{r} objects, of which \eqn{m} are of the type I and
@@ -73,11 +74,6 @@ dist_hypergeometric <- function(m, n, k){
   new_dist(m = m, n = n, k = k, class = "dist_hypergeometric")
 }
 
-#' @export
-print.dist_hypergeometric <- function(x, ...){
-  cat(format(x, ...))
-}
-
 #' @export
 format.dist_hypergeometric <- function(x, digits = 2, ...){
   sprintf(
@@ -120,7 +116,7 @@ mean.dist_hypergeometric <- function(x, ...){
 }
 
 #' @export
-variance.dist_hypergeometric <- function(x, ...){
+covariance.dist_hypergeometric <- function(x, ...){
   m <- x[["m"]]
   n <- x[["n"]]
   k <- x[["k"]]
