@@ -1,13 +1,28 @@
 #' The Poisson-Inverse Gaussian distribution
 #'
-#' \lifecycle{stable}
+#' @description
+#' `r lifecycle::badge('stable')`
 #'
 #' @inheritParams actuar::dpoisinvgauss
 #'
 #' @seealso [actuar::PoissonInverseGaussian]
 #'
 #' @examples
-#' dist_poisson_inverse_gaussian(mean = rep(0.1, 3), shape = c(0.4, 0.8, 1))
+#' dist <- dist_poisson_inverse_gaussian(mean = rep(0.1, 3), shape = c(0.4, 0.8, 1))
+#' dist
+#'
+#' @examplesIf requireNamespace("actuar", quietly = TRUE)
+#' mean(dist)
+#' variance(dist)
+#' support(dist)
+#' generate(dist, 10)
+#'
+#' density(dist, 2)
+#' density(dist, 2, log = TRUE)
+#'
+#' cdf(dist, 4)
+#'
+#' quantile(dist, 0.7)
 #'
 #' @name dist_poisson_inverse_gaussian
 #' @export
@@ -23,11 +38,6 @@ dist_poisson_inverse_gaussian <- function(mean, shape){
   new_dist(m = mean, s = shape, class = "dist_poisson_inverse_gaussian")
 }
 
-#' @export
-print.dist_poisson_inverse_gaussian <- function(x, ...){
-  cat(format(x, ...))
-}
-
 #' @export
 format.dist_poisson_inverse_gaussian <- function(x, digits = 2, ...){
   sprintf(
@@ -73,6 +83,6 @@ mean.dist_poisson_inverse_gaussian <- function(x, ...){
 }
 
 #' @export
-variance.dist_poisson_inverse_gaussian <- function(x, ...){
+covariance.dist_poisson_inverse_gaussian <- function(x, ...){
   x[["m"]]/x[["s"]] * (x[["m"]]^2 + x[["s"]])
 }
